==> kubernetes-model-apiextensions-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface CustomResourceConversionFluent<A extends CustomResourceConversionFluent<A>> extends Fluent<A>{
  public String getStrategy();
  public A withStrategy(String strategy);
  public Boolean hasStrategy();
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookConversion getWebhook();
  public WebhookConversion buildWebhook();
  public A withWebhook(WebhookConversion webhook);
  public Boolean hasWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> withNewWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> withNewWebhookLike(WebhookConversion item);
  public CustomResourceConversionFluent.WebhookNested<A> editWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhookLike(WebhookConversion item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface WebhookNested<N> extends Nested<N>,WebhookConversionFluent<CustomResourceConversionFluent.WebhookNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}

==> kubernetes-model-apiextensions-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface CustomResourceConversionFluent<A extends CustomResourceConversionFluent<A>> extends Fluent<A>{
  public String getStrategy();
  public A withStrategy(String strategy);
  public Boolean hasStrategy();
  
  /**
   * This method has been deprecated, please use method buildWebhook instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebhookConversion getWebhook();
  public WebhookConversion buildWebhook();
  public A withWebhook(WebhookConversion webhook);
  public Boolean hasWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> withNewWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> withNewWebhookLike(WebhookConversion item);
  public CustomResourceConversionFluent.WebhookNested<A> editWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhook();
  public CustomResourceConversionFluent.WebhookNested<A> editOrNewWebhookLike(WebhookConversion item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface WebhookNested<N> extends Nested<N>,WebhookConversionFluent<CustomResourceConversionFluent.WebhookNested<N>>{
    public N and();
    public N endWebhook();
    
  }
  
}
